==> anki-24.06.3.gh.tar.gz: anki-24.06.3/ts/lib/tslib/help-page.ts <==
// Copyright: Ankitects Pty Ltd and contributors
// License: GNU AGPL, version 3 or later; http://www.gnu.org/licenses/agpl.html

/** These links are checked in CI to ensure they are valid. */
export const HelpPage = {
    DeckOptions: {
        maximumInterval: "https://docs.ankiweb.net/deck-options.html#maximum-interval",
        startingEase: "https://docs.ankiweb.net/deck-options.html#starting-ease",
        easyBonus: "https://docs.ankiweb.net/deck-options.html#easy-bonus",
        intervalModifier: "https://docs.ankiweb.net/deck-options.html#interval-modifier",
        hardInterval: "https://docs.ankiweb.net/deck-options.html#hard-interval",
        newInterval: "https://docs.ankiweb.net/deck-options.html#new-interval",
        advanced: "https://docs.ankiweb.net/deck-options.html#advanced",
        timer: "https://docs.ankiweb.net/deck-options.html#timer",
        autoAdvance: "https://docs.ankiweb.net/deck-options.html#auto-advance",
        learningSteps: "https://docs.ankiweb.net/deck-options.html#learning-steps",
        graduatingInterval: "https://docs.ankiweb.net/deck-options.html#graduating-interval",
        easyInterval: "https://docs.ankiweb.net/deck-options.html#easy-interval",
        insertionOrder: "https://docs.ankiweb.net/deck-options.html#insertion-order",
        newCards: "https://docs.ankiweb.net/deck-options.html#new-cards",
        relearningSteps: "https://docs.ankiweb.net/deck-options.html#relearning-steps",
        minimumInterval: "https://docs.ankiweb.net/deck-options.html#minimum-interval",
        lapses: "https://docs.ankiweb.net/deck-options.html#lapses",
        displayOrder: "https://docs.ankiweb.net/deck-options.html#display-order",
        maximumReviewsday: "https://docs.ankiweb.net/deck-options.html#maximum-reviewsday",
        newCardsday: "https://docs.ankiweb.net/deck-options.html#new-cardsday",
        dailyLimits: "https://docs.ankiweb.net/deck-options.html#daily-limits",
        audio: "https://docs.ankiweb.net/deck-options.html#audio",
        fsrs: "http://docs.ankiweb.net/deck-options.html#fsrs",
    },
    Leeches: {
        leeches: "https://docs.ankiweb.net/leeches.html#leeches",
        waiting: "https://docs.ankiweb.net/leeches.html#waiting",
    },
    Studying: {
        siblingsAndBurying: "https://docs.ankiweb.net/studying.html#siblings-and-burying",
    },
    PackageImporting: {
        root: "https://docs.ankiweb.net/importing/packaged-decks.html",
        updating: "https://docs.ankiweb.net/importing/packaged-decks.html#updating",
        scheduling: "https://docs.ankiweb.net/importing/packaged-decks.html#scheduling",
    },
    TextImporting: {
        root: "https://docs.ankiweb.net/importing/text-files.html",
        updating: "https://docs.ankiweb.net/importing/text-files.html#duplicates-and-updating",
        html: "https://docs.ankiweb.net/importing/text-files.html#html",
    },
};

==> anki-25.07.1.gh.tar.gz: anki-25.07.1/ts/lib/tslib/help-page.ts <==
// Copyright: Ankitects Pty Ltd and contributors
// License: GNU AGPL, version 3 or later; http://www.gnu.org/licenses/agpl.html

/** These links are checked in CI to ensure they are valid. */
export const HelpPage = {
    DeckOptions: {
        maximumInterval: "https://docs.ankiweb.net/deck-options.html#maximum-interval",
        startingEase: "https://docs.ankiweb.net/deck-options.html#starting-ease",
        easyBonus: "https://docs.ankiweb.net/deck-options.html#easy-bonus",
        intervalModifier: "https://docs.ankiweb.net/deck-options.html#interval-modifier",
        hardInterval: "https://docs.ankiweb.net/deck-options.html#hard-interval",
        newInterval: "https://docs.ankiweb.net/deck-options.html#new-interval",
        advanced: "https://docs.ankiweb.net/deck-options.html#advanced",
        timer: "https://docs.ankiweb.net/deck-options.html#timers",
        autoAdvance: "https://docs.ankiweb.net/deck-options.html#auto-advance",
        learningSteps: "https://docs.ankiweb.net/deck-options.html#learning-steps",
        graduatingInterval: "https://docs.ankiweb.net/deck-options.html#graduating-interval",
        easyInterval: "https://docs.ankiweb.net/deck-options.html#easy-interval",
        insertionOrder: "https://docs.ankiweb.net/deck-options.html#insertion-order",
        newCards: "https://docs.ankiweb.net/deck-options.html#new-cards",
        relearningSteps: "https://docs.ankiweb.net/deck-options.html#relearning-steps",
        minimumInterval: "https://docs.ankiweb.net/deck-options.html#minimum-interval",
        lapses: "https://docs.ankiweb.net/deck-options.html#lapses",
        displayOrder: "https://docs.ankiweb.net/deck-options.html#display-order",
        maximumReviewsday: "https://docs.ankiweb.net/deck-options.html#maximum-reviewsday",
        newCardsday: "https://docs.ankiweb.net/deck-options.html#new-cardsday",
        dailyLimits: "https://docs.ankiweb.net/deck-options.html#daily-limits",
        audio: "https://docs.ankiweb.net/deck-options.html#audio",
        fsrs: "http://docs.ankiweb.net/deck-options.html#fsrs",
    },
    Leeches: {
        leeches: "https://docs.ankiweb.net/leeches.html#leeches",
        waiting: "https://docs.ankiweb.net/leeches.html#waiting",
    },
    Studying: {
        siblingsAndBurying: "https://docs.ankiweb.net/studying.html#siblings-and-burying",
    },
    PackageImporting: {
        root: "https://docs.ankiweb.net/importing/packaged-decks.html",
        updating: "https://docs.ankiweb.net/importing/packaged-decks.html#updating",
        scheduling: "https://docs.ankiweb.net/importing/packaged-decks.html#scheduling",
    },
    TextImporting: {
        root: "https://docs.ankiweb.net/importing/text-files.html",
        updating: "https://docs.ankiweb.net/importing/text-files.html#duplicates-and-updating",
        html: "https://docs.ankiweb.net/importing/text-files.html#html",
    },
};
